@@ -1,21 +1,18 @@
-
 package TComparable;
 
 use strict;
-use warnings; 
+use warnings;
 
 our $VERSION = '0.01';
-	
+
 ## we are a trait
 use Class::Trait 'base';
 
 use Class::Trait qw(TEquality);
-	
+
 ## overload operator
 
-our %OVERLOADS = (
-		'<=>' => "compare"
-		 );
+our %OVERLOADS = ( '<=>' => "compare" );
 
 ## requires methods
 
@@ -23,27 +20,27 @@ our @REQUIRES = qw(compare);
 
 ### methods
 
-# The equals method is there to provide 
+# The equals method is there to provide
 # specific handler for the '==' operator (and
-# to be sure about how '!=' will react, we 
+# to be sure about how '!=' will react, we
 # override the autogeneration with the _notEquals
-# method).  
-# This is here so that one can deal with '==' and '!=' 
-# and not the '<', '<=', '<=>', '=>', '>' operators. 
-# NOTE: 
+# method).
+# This is here so that one can deal with '==' and '!='
+# and not the '<', '<=', '<=>', '=>', '>' operators.
+# NOTE:
 # Our default implementation of equals actually defers
 # to the compare method, and the _notEquals method
 # actually defers to the value of equals (and returns
-# the inverse), so that an object which wants all 
+# the inverse), so that an object which wants all
 # the operators ('<=>' and co.) will be able to use
 # the '==' and '!=' operators without an issue.
-# If however compare is not defined, a 
+# If however compare is not defined, a
 # MethodNotImplemented exception will be thrown.
 # This retains backwards compatability while still
 # allowing for specialization.
 sub equalTo {
-	my ($left, $right) = @_;
-	return ($left->compare($right) == 0) ? 1 : 0;
+    my ( $left, $right ) = @_;
+    return ( $left->compare($right) == 0 ) ? 1 : 0;
 }
 
 1;
@@ -57,7 +54,8 @@ TComparable - Trait for adding comparison abilities to your object
 
 =head1 DESCRIPTION
 
-This trait gives your object a wide range of comparison abilities through its overloading of the E<lt>=E<gt> operator.
+This trait gives your object a wide range of comparison abilities through its
+overloading of the E<lt>=E<gt> operator.
 
 =head1 SUB-TRAITS
 
@@ -67,13 +65,14 @@ This trait gives your object a wide range of comparison abilities through its ov
 
 =back
 
-=head1 REQUIREMENTS
+=head1 REQUIRES
 
 =over 4
 
 =item B<compare ($left, $right)>
 
-This method should return -1 if C<$left> is less than C<$right>, 0 if C<$left> is equal to C<$right>, and 1 if C<$left> is greater than C<$right>.
+This method should return -1 if C<$left> is less than C<$right>, 0 if C<$left>
+is equal to C<$right>, and 1 if C<$left> is greater than C<$right>.
 
 =back
 
@@ -85,7 +84,7 @@ This method should return -1 if C<$left> is less than C<$right>, 0 if C<$left> i
 
 =back
 
-=head1 METHODS
+=head1 PROVIDES
 
 =over 4
 
@@ -105,7 +104,7 @@ Copyright 2004, 2005 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com> 
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself. 
 
 =cut
